==> mocca_edc-0.1.0-py3-none-any.whl: mocca_auth/codenames/auditor.py <==
from edc_auth.codenames import auditor

auditor += [
    "mocca_lists.view_arvregimens",
    "mocca_lists.view_clinicservices",
    "mocca_lists.view_conditions",
    "mocca_lists.view_healthservices",
    "mocca_lists.view_offstudyreasons",
    "mocca_prn.view_endofstudy",
    "mocca_prn.view_historicalendofstudy",
    "mocca_prn.view_historicallosstofollowup",
    "mocca_prn.view_historicallosstofollowuphiv",
    "mocca_prn.view_historicallosstofollowupncd",
    "mocca_prn.view_historicaloffschedulehiv",
    "mocca_prn.view_historicaloffschedulencd",
    "mocca_prn.view_historicalonschedulehiv",
    "mocca_prn.view_historicalonschedulencd",
    "mocca_prn.view_historicalprotocoldeviationviolation",
    "mocca_prn.view_losstofollowup",
    "mocca_prn.view_losstofollowuphiv",
    "mocca_prn.view_losstofollowupncd",
    "mocca_prn.view_offschedulehiv",
    "mocca_prn.view_offschedulencd",
    "mocca_prn.view_onschedulehiv",
    "mocca_prn.view_onschedulencd",
    "mocca_prn.view_protocoldeviationviolation",
    "mocca_prn.view_unblindingrequestoruser",
    "mocca_prn.view_unblindingrevieweruser",
    "mocca_screening.view_dailyclosinglog",
    "mocca_screening.view_historicaldailyclosinglog",
    "mocca_screening.view_historicalsubjectrefusal",
    "mocca_screening.view_historicalsubjectscreening",
    "mocca_screening.view_subjectrefusal",
    "mocca_screening.view_subjectscreening",
    "mocca_subject.view_cd4result",
    "mocca_subject.view_clinicalreview",
    "mocca_subject.view_clinicalreviewbaseline",
    "mocca_subject.view_complicationsbaseline",
    "mocca_subject.view_complicationsfollowup",
    "mocca_subject.view_dminitialreview",
    "mocca_subject.view_dmreview",
    "mocca_subject.view_familyhistory",
    "mocca_subject.view_glucose",
    "mocca_subject.view_healtheconomicsrevised",
    "mocca_subject.view_historicalcd4result",
    "mocca_subject.view_historicalclinicalreview",
    "mocca_subject.view_historicalclinicalreviewbaseline",
    "mocca_subject.view_historicalcomplicationsfollowup",
    "mocca_subject.view_historicalcomplicationsbaseline",
    "mocca_subject.view_historicaldminitialreview",
    "mocca_subject.view_historicaldmreview",
    "mocca_subject.view_historicalfamilyhistory",
    "mocca_subject.view_historicalhealtheconomicsrevised",
    "mocca_subject.view_historicalhivinitialreview",
    "mocca_subject.view_historicalhivreview",
    "mocca_subject.view_historicalhtninitialreview",
    "mocca_subject.view_historicalhtnreview",
    "mocca_subject.view_historicalhivmedicationadherence",
    "mocca_subject.view_historicaldmmedicationadherence",
    "mocca_subject.view_historicalhtnmedicationadherence",
    "mocca_subject.view_historicalindicators",
    "mocca_subject.view_historicalmedications",
    "mocca_subject.view_historicalnextappointment",
    "mocca_subject.view_historicalotherbaselinedata",
    "mocca_subject.view_historicalsubjectrequisition",
    "mocca_subject.view_historicalsubjectvisit",
    "mocca_subject.view_historicalsubjectvisitmissed",
    "mocca_subject.view_historicalviralloadresult",
    "mocca_subject.view_hivinitialreview",
    "mocca_subject.view_hivreview",
    "mocca_subject.view_htninitialreview",
    "mocca_subject.view_htnreview",
    "mocca_subject.view_hivmedicationadherence",
    "mocca_subject.view_dmmedicationadherence",
    "mocca_subject.view_htnmedicationadherence",
    "mocca_subject.view_indicators",
    "mocca_subject.view_medications",
    "mocca_subject.view_nextappointment",
    "mocca_subject.view_otherbaselinedata",
    "mocca_subject.view_subjectrequisition",
    "mocca_subject.view_subjectvisit",
    "mocca_subject.view_subjectvisitmissed",
    "mocca_subject.view_viralloadresult",
]
auditor.sort()

==> mocca_edc-0.1.3-py3-none-any.whl: mocca_auth/codenames/auditor.py <==
from edc_auth.codenames import auditor

auditor += [
    "mocca_lists.view_arvregimens",
    "mocca_lists.view_clinicservices",
    "mocca_lists.view_conditions",
    "mocca_lists.view_healthservices",
    "mocca_lists.view_offstudyreasons",
    "mocca_prn.view_endofstudy",
    "mocca_prn.view_historicalendofstudy",
    "mocca_prn.view_historicallosstofollowup",
    "mocca_prn.view_historicaloffschedule",
    "mocca_prn.view_historicalonschedule",
    "mocca_prn.view_historicalprotocoldeviationviolation",
    "mocca_prn.view_losstofollowup",
    "mocca_prn.view_offschedule",
    "mocca_prn.view_onschedule",
    "mocca_prn.view_protocoldeviationviolation",
    "mocca_prn.view_unblindingrequestoruser",
    "mocca_prn.view_unblindingrevieweruser",
    "mocca_screening.view_dailyclosinglog",
    "mocca_screening.view_historicaldailyclosinglog",
    "mocca_screening.view_historicalsubjectrefusal",
    "mocca_screening.view_historicalsubjectscreening",
    "mocca_screening.view_subjectrefusal",
    "mocca_screening.view_subjectscreening",
    "mocca_subject.view_cd4result",
    "mocca_subject.view_clinicalreview",
    "mocca_subject.view_clinicalreviewbaseline",
    "mocca_subject.view_complicationsbaseline",
    "mocca_subject.view_complicationsfollowup",
    "mocca_subject.view_dminitialreview",
    "mocca_subject.view_dmreview",
    "mocca_subject.view_familyhistory",
    "mocca_subject.view_glucose",
    "mocca_subject.view_healtheconomicsrevised",
    "mocca_subject.view_historicalcd4result",
    "mocca_subject.view_historicalclinicalreview",
    "mocca_subject.view_historicalclinicalreviewbaseline",
    "mocca_subject.view_historicalcomplicationsfollowup",
    "mocca_subject.view_historicalcomplicationsbaseline",
    "mocca_subject.view_historicaldminitialreview",
    "mocca_subject.view_historicaldmreview",
    "mocca_subject.view_historicalfamilyhistory",
    "mocca_subject.view_historicalhealtheconomicsrevised",
    "mocca_subject.view_historicalhivinitialreview",
    "mocca_subject.view_historicalhivreview",
    "mocca_subject.view_historicalhtninitialreview",
    "mocca_subject.view_historicalhtnreview",
    "mocca_subject.view_historicalhivmedicationadherence",
    "mocca_subject.view_historicaldmmedicationadherence",
    "mocca_subject.view_historicalhtnmedicationadherence",
    "mocca_subject.view_historicalindicators",
    "mocca_subject.view_historicalmedications",
    "mocca_subject.view_historicalnextappointment",
    "mocca_subject.view_historicalotherbaselinedata",
    "mocca_subject.view_historicalsubjectrequisition",
    "mocca_subject.view_historicalsubjectvisit",
    "mocca_subject.view_historicalsubjectvisitmissed",
    "mocca_subject.view_historicalviralloadresult",
    "mocca_subject.view_hivinitialreview",
    "mocca_subject.view_hivreview",
    "mocca_subject.view_htninitialreview",
    "mocca_subject.view_htnreview",
    "mocca_subject.view_hivmedicationadherence",
    "mocca_subject.view_dmmedicationadherence",
    "mocca_subject.view_htnmedicationadherence",
    "mocca_subject.view_indicators",
    "mocca_subject.view_medications",
    "mocca_subject.view_nextappointment",
    "mocca_subject.view_otherbaselinedata",
    "mocca_subject.view_subjectrequisition",
    "mocca_subject.view_subjectvisit",
    "mocca_subject.view_subjectvisitmissed",
    "mocca_subject.view_viralloadresult",
]
auditor.sort()
